URL Converter for Python
========================

A base class for implementing simple URL converters.

License
-------

MIT license.

Author
------

The package is written and maintained by Curt Gilman.
